@@ -53,7 +53,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_volume_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '5')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '5')
-        is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'nova')
         is_expected.to contain_nova_config('api/fping_path').with('value' => '/usr/sbin/fping')
         is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/metadata_cache_expiration').with('value' => '<SERVICE DEFAULT>')
@@ -102,7 +101,6 @@ describe 'nova::api' do
           :neutron_metadata_proxy_shared_secret        => 'secrete',
           :osapi_compute_workers                       => 1,
           :metadata_workers                            => 2,
-          :default_floating_pool                       => 'public',
           :enable_proxy_headers_parsing                => true,
           :metadata_cache_expiration                   => 15,
           :vendordata_jsonfile_path                    => '/tmp',
@@ -156,7 +154,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/use_forwarded_for').with('value' => false)
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
-        is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'public')
         is_expected.to contain_nova_config('api/metadata_cache_expiration').with('value' => '15')
         is_expected.to contain_nova_config('api/vendordata_jsonfile_path').with('value' => '/tmp')
         is_expected.to contain_nova_config('api/vendordata_providers').with('value' => 'StaticJSON,DynamicJSON')
@@ -187,7 +184,7 @@ describe 'nova::api' do
       end
 
       it 'configures nova pci_alias entries' do
-        is_expected.to contain_nova_config('pci/pci_alias').with(
+        is_expected.to contain_nova_config('pci/alias').with(
           'value' => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
         )
       end
@@ -199,17 +196,11 @@ describe 'nova::api' do
           :validate => true,
         })
       end
-      it { is_expected.to contain_exec('execute nova-api validation').with(
-        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider  => 'shell',
-        :tries     => '10',
-        :try_sleep => '2',
+      it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
         :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username nova --os-password passw0rd flavor-list',
+        :subscribe => 'Service[nova-api]',
       )}
 
-      it { is_expected.to contain_anchor('create nova-api anchor').with(
-        :require => 'Exec[execute nova-api validation]',
-      )}
     end
 
     context 'while validating the service with custom command' do
@@ -219,16 +210,9 @@ describe 'nova::api' do
           :validation_options  => { 'nova-api' => { 'command' => 'my-script' } }
         })
       end
-      it { is_expected.to contain_exec('execute nova-api validation').with(
-        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider  => 'shell',
-        :tries     => '10',
-        :try_sleep => '2',
+      it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
         :command   => 'my-script',
-      )}
-
-      it { is_expected.to contain_anchor('create nova-api anchor').with(
-        :require => 'Exec[execute nova-api validation]',
+        :subscribe => 'Service[nova-api]',
       )}
     end
 
